@@ -20,8 +20,8 @@ from LivestockCV.core.crop import crop
 from LivestockCV.core.invert import invert
 from LivestockCV.core import roi
 from LivestockCV.core import threshold
-from LivestockCV.core import gaussian_blur
-from LivestockCV.core import analyze_color
+from LivestockCV.core.gaussian_blur import gaussian_blur
+from LivestockCV.core.analyze_color import analyze_color
 # add new functions to end of lists
 
 # Auto versioning
